==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 */
$lang['menu']                  = 'Administri Kromaĵojn';
$lang['download']              = 'Elŝuti kaj instali novan kromaĵon';
$lang['manage']                = 'Instalitaj Kromaĵoj';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'ĝisdatigo';
$lang['btn_delete']            = 'forigi';
$lang['btn_settings']          = 'agordoj';
$lang['btn_download']          = 'Elŝuti';
$lang['btn_enable']            = 'Konservi';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalite:';
$lang['lastupdate']            = 'Laste ĝisdatigite:';
$lang['source']                = 'Fonto:';
$lang['unknown']               = 'nekonate';
$lang['updating']              = 'Ĝisdatiganta ...';
$lang['updated']               = 'Kromaĵo %s estas sukcese ĝisdatigita';
$lang['updates']               = 'La jenaj kromaĵoj estas sukcese ĝisdatigitaj';
$lang['update_none']           = 'Neniu ĝisdatigo troviĝas.';
$lang['deleting']              = 'Foriganta ...';
$lang['deleted']               = 'Kromaĵo %s estas forigita.';
$lang['downloading']           = 'Elŝutanta ...';
$lang['downloaded']            = 'La kromaĵo %s estas sukcese instalita';
$lang['downloads']             = 'La jenaj kromaĵoj estas sukcese instalitaj:';
$lang['download_none']         = 'Neniu kromaĵo troveblas, aŭ eble okazis nekonata problemo dum elŝuto kaj instalo.';
$lang['plugin']                = 'Kromaĵo:';
$lang['components']            = 'Komponeroj';
$lang['noinfo']                = 'Tiu ĉi kromaĵo liveris neniun informon: eble ĝi ne validas.';
$lang['name']                  = 'Nomo:';
$lang['date']                  = 'Dato:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Priskribo:';
$lang['author']                = 'Aŭtoro:';
$lang['www']                   = 'Retpaĝo:';
$lang['error']                 = 'Nekonata eraro okazis.';
$lang['error_download']        = 'Maleblas elŝuti la kromaĵan dosieron: %s';
$lang['error_badurl']          = 'Suspektinda malbona URL - maleblas difini la dosieran nomon el la URL';
$lang['error_dircreate']       = 'Maleblas krei intertempan dosierujon por enhavi elŝutaĵon';
$lang['error_decompress']      = 'La administrilo de kromaĵoj ne kapablis malkompakti la elŝutitan dosieron. Tio povas esti pro malkompleta elŝuto, tiaokaze vi devus provi refoje; aŭ eble la kompakta formato ne estas konata, tiaokaze vi bezonos elŝuti kaj instali la kromaĵon malaŭtomate.';
$lang['error_copy']            = 'Okazis eraro de dosierkopio dum provo instali dosierojn por la kromaĵo <em>%s</em>: la disko povus esti plenplena aux aliro-rajtoj povus esti misdifinitaj. Tio povus rezulti en malkomplete instalita kromaĵo kaj igi vian vikion malstabilan.';
$lang['error_delete']          = 'Okazis eraro dum provo forigi la kromaĵon <em>%s</em>. Plejprobable tio sekvas de nesufiĉa rajto por aliri la dosieron aŭ ties ujon.';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 */
$lang['menu']                  = 'Administri Kromaĵojn';
$lang['download']              = 'Elŝuti kaj instali novan kromaĵon';
$lang['manage']                = 'Instalitaj Kromaĵoj';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'ĝisdatigo';
$lang['btn_delete']            = 'forigi';
$lang['btn_settings']          = 'agordoj';
$lang['btn_download']          = 'Elŝuti';
$lang['btn_enable']            = 'Konservi';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalite:';
$lang['lastupdate']            = 'Laste ĝisdatigite:';
$lang['source']                = 'Fonto:';
$lang['unknown']               = 'nekonate';
$lang['updating']              = 'Ĝisdatiganta ...';
$lang['updated']               = 'Kromaĵo %s estas sukcese ĝisdatigita';
$lang['updates']               = 'La jenaj kromaĵoj estas sukcese ĝisdatigitaj';
$lang['update_none']           = 'Neniu ĝisdatigo troviĝas.';
$lang['deleting']              = 'Foriganta ...';
$lang['deleted']               = 'Kromaĵo %s estas forigita.';
$lang['downloading']           = 'Elŝutanta ...';
$lang['downloaded']            = 'La kromaĵo %s estas sukcese instalita';
$lang['downloads']             = 'La jenaj kromaĵoj estas sukcese instalitaj:';
$lang['download_none']         = 'Neniu kromaĵo troveblas, aŭ eble okazis nekonata problemo dum elŝuto kaj instalo.';
$lang['plugin']                = 'Kromaĵo:';
$lang['components']            = 'Komponeroj';
$lang['noinfo']                = 'Tiu ĉi kromaĵo liveris neniun informon: eble ĝi ne validas.';
$lang['name']                  = 'Nomo:';
$lang['date']                  = 'Dato:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Priskribo:';
$lang['author']                = 'Aŭtoro:';
$lang['www']                   = 'Retpaĝo:';
$lang['error']                 = 'Nekonata eraro okazis.';
$lang['error_download']        = 'Maleblas elŝuti la kromaĵan dosieron: %s';
$lang['error_badurl']          = 'Suspektinda malbona URL - maleblas difini la dosieran nomon el la URL';
$lang['error_dircreate']       = 'Maleblas krei provizoran dosierujon por ricevi elŝutaĵon';
$lang['error_decompress']      = 'La administrilo de kromaĵoj ne kapablis malkompakti la elŝutitan dosieron. Tio povas esti pro malkompleta elŝuto, tiaokaze vi devus provi refoje; aŭ eble la kompakta formato ne estas konata, tiaokaze vi bezonos elŝuti kaj instali la kromaĵon malaŭtomate.';
$lang['error_copy']            = 'Okazis eraro de dosierkopio dum provo instali dosierojn por la kromaĵo <em>%s</em>: la disko povus esti plenplena aux aliro-rajtoj povus esti misdifinitaj. Tio povus rezulti en malkomplete instalita kromaĵo kaj igi vian vikion malstabilan.';
$lang['error_delete']          = 'Okazis eraro dum provo forigi la kromaĵon <em>%s</em>. Plejprobable tio sekvas de nesufiĉa rajto por aliri la dosieron aŭ ties ujon.';
$lang['enabled']               = 'La kromaĵo %s estas ebligita.';
$lang['notenabled']            = 'La kromaĵo %s ne povis esti ebligita, kontrolu dosier-permesojn.';
$lang['disabled']              = 'La kromaĵo %s estas malebligita.';
$lang['notdisabled']           = 'La kromaĵo %s ne povis esti malebligita, kontrolu dosier-permesojn.';
